@@ -5,7 +5,7 @@ import logging
 LOGGER = logging.getLogger('pyShelly')
 
 NAME = "pyShelly"
-VERSION = "0.2.10"
+VERSION = "0.2.11"
 
 COAP_IP = "224.0.1.187"
 COAP_PORT = 5683
@@ -55,6 +55,7 @@ STATUS_RESPONSE_ROLLERS_TOTAL = 'total'
 SENSOR_UNAVAILABLE_SEC = 3600 * 13 #13 hours
 
 INFO_VALUE_RSSI = 'rssi'
+INFO_VALUE_RSSI_LEVEL = 'rssi_level'
 INFO_VALUE_UPTIME = 'uptime'
 INFO_VALUE_OVER_POWER = 'over_power'
 INFO_VALUE_DEVICE_TEMP = 'device_temp'
@@ -153,7 +154,8 @@ SHELLY_TYPES = {
     'SHIX3-1': {'name': "Shelly i3", 'mqtt':'shellyix3'},
     'SHGS-1': {'name': "Shelly Gas", 'mqtt':'shellygas'},
     'SHAIR-1': {'name': "Shelly Air", 'mqtt':'ShellyAir'},
-    'SHPLUG-U1': {'name': "Shelly Plug US", 'mqtt':'shellyplugu1'}
+    'SHPLUG-U1': {'name': "Shelly Plug US", 'mqtt':'shellyplugu1'},
+    'SHUNI-1': {'name': "Shelly UNI", 'mqtt':'shellyuni'}
 }
 
 EFFECTS_RGBW2 = [
@@ -172,3 +174,10 @@ EFFECTS_BULB = [
     {'name': "On/off gradual", 'effect': 5},
     {'name':"Red/green change", 'effect': 6},
 ]
+
+RSSI_LEVELS = {
+    -50 : "excelent",
+    -60 : "very good",
+    -70 : "good",
+    -1000: "weak"
+}
\ No newline at end of file
